<?php 
class WP_Business_Builder{

	public function __construct(){
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
		add_filter( 'body_class', array( $this, 'body_class' ) );
	}

	public function body_class( $classes ){
		$enable_sticky = wp_deep_blue_get( 'enable-sticky-header' );
		if( $enable_sticky ){
			$classes[] = 'wp-db-sticky-header';
		}

		return $classes;
	}

	public function scripts(){
		
		wp_enqueue_style( 'wp-business-builder', get_template_directory_uri() . '/style.css', array(), '1.0' );
		$scripts = array( 
			'sticky' => array(
				'version'  => '1.0.4',
				'no-style' => true
			),
		);

		wp_enqueue_script( 'wp-business-builder-script', get_stylesheet_directory_uri() . '/assets/script.js', array( 'jquery' ), '1.0' );
		wp_deep_blue_enqueue_scripts( $scripts, "assets/vendors" );
	}

}

new WP_Business_Builder();

if( !function_exists( 'wp_deep_blue_has_sidebar' ) ){
	/**
	 * Determines if the page needs sidebar
	 * @since WP Deep Blue 1.0
	 */
	function wp_deep_blue_has_sidebar(){
		if( is_search() ){
			return false;
		}elseif( is_singular( 'post' ) || is_page() || is_home() ){

			if( is_home() && is_front_page() ){
				$pos = wp_deep_blue_get( 'sidebar-position' );
				return $pos == 'hide' ? false : true;
			}

			if( is_front_page() ){
				return false;
			}
			
			$id = wp_deep_blue_get_page_id();
			$meta_id = 'wp-deep-blue-sidebar-position';
			if( "hide" == get_post_meta( $id, $meta_id, true ) ){
				return false;
			}

			return true;
		}else{
			$pos = wp_deep_blue_get( 'sidebar-position' );
			return $pos == 'hide' ? false : true;
		}
	}
}

function wp_business_builder_body_class( $classes ){

	if( wp_deep_blue_has_sidebar() ){

		if( is_singular( 'post' ) || is_page() || is_home() ){

			if( is_home() && is_front_page() ){
				$pos = wp_deep_blue_get( 'sidebar-position' );
				$classes[] = 'sidebar-' . $pos;
				return $classes;
			}

			$id = wp_deep_blue_get_page_id();
			$meta_id = 'wp-deep-blue-sidebar-position';
			$pos = get_post_meta( $id, $meta_id, true );
			if( empty( $pos ) ){
				$pos = 'right';
			}
			
			$classes[] = 'sidebar-' . $pos;
			return $classes;

		}else{
			$pos = wp_deep_blue_get( 'sidebar-position' );
			$classes[] = 'sidebar-' . $pos;
			return $classes;
		}
	}

	return $classes;
}
add_filter( 'body_class', 'wp_business_builder_body_class' );